TSSV: Targeted characterisation of short structural variation
=============================================================

TSSV is a program that does targeted characterisation of short structural
variation. It can be used for STR analysis, or any other type of targeted
analysis. It characterises any variation between a set of user-defined markers.

TSSV is platform-independent. It has been tested on Linux, macOS, and Windows.

Please see ReadTheDocs_ for the latest documentation.


.. _ReadTheDocs: https://tssv.readthedocs.io/en/latest/index.html
